Crate amqp_lapin_helper

Crate amqp_lapin_helper 

Modules

flags
Helpers to handle AMQP flags.
generation
Generation utilities for the various AMQP types.
message
options
parsing
Parsing utilities for the various AMQP types.
types

Structs

AccessRequestOptions
BasicAckOptions
BasicCancelOptions
BasicConsumeOptions
BasicDeliverOptions
BasicGetOkOptions
BasicGetOptions
BasicNackOptions
BasicPublishOptions
BasicQosOptions
BasicRecoverAsyncOptions
BasicRecoverOptions
BasicRejectOptions
Broker
AMQP Client
ByteArray
An array of bytes (RabbitMQ specific)
Channel
Main entry point for most AMQP operations.
ChannelFlowOkOptions
ChannelFlowOptions
ConfirmSelectOptions
Connection
A TCP connection to the AMQP server.
ConnectionProperties
Consumer
DecimalValue
A Decimal value composed of a scale and a value
Delivery
A received AMQP message.
ExchangeBindOptions
ExchangeDeclareOptions
ExchangeDeleteOptions
ExchangeUnbindOptions
FieldArray
An array of AMQPValue
FieldTable
A Map<String, AMQPValue>
LapinConsumer
Continuously consumes message from a Queue.
Listener
LongString
A String
Publisher
needs to be a MPSC queue, in order there’s a disconnection, messages still could be added to the queue but needs to wait to be connected to AMQP in order to process the queue and send the msg on the broker maybe have a “PublisherQueue”
PublisherQueue
Queue
QueueBindOptions
QueueDeclareOptions
QueueDeleteOptions
QueueMessage
QueuePurgeOptions
RateLimiter
A token-bucket rate limiter.
Ready
This will send a copy of the receiver to receive a signal that says the consumer & publisher are ready so we could start the software and making sure we’ve haven’t missed any messages.
ShortString
A String (deprecated)

Enums

AMQPType
Enumeration referencing all the available AMQP types
AMQPValue
Enumeration referencing the possible AMQP values depending on the types
Error
ExchangeKind

Traits

BrokerListener
Plug listeners to the broker.
BrokerManager
BrokerPublish
Tag an object as Publishable

Type Aliases

BasicProperties
Type alias for AMQP BasicProperties
Boolean
A bool
ChannelId
A Channel identifier
ChunkSize
The size of a chunk of a delivery’s payload
ConsumeResult
ConsumerCount
The number of consumers
DeliveryTag
A delivery tag
Double
A f64
Float
A f32
FrameSize
the size of an AMQP frame
Heartbeat
The maximum heartbeat interval
Identifier
An identifier (class id or method id)
LongInt
An i32
LongLongInt
An i64
LongLongUInt
A u64
LongUInt
A u32
MessageCount
The number of messages
PayloadSize
The size of a delivery’s payload
ReplyCode
A reply code (for closing channels and connections)
Requeue
Result
ShortInt
An i16
ShortShortInt
An i8
ShortShortUInt
A u8
ShortUInt
A u16
Timestamp
A timestamp (u64)
Void
No value